@@ -48,15 +48,21 @@ TRACE_APPROX_CANDIDATES = False
 TRACE_APPROX_MATCHES = False
 TRACE_INDEXING_PERF = False
 TRACE_TOKEN_DOC_FREQ = False
+TRACE_SPDX_LID = False
 
 
 def logger_debug(*args):
     pass
 
 
-if (TRACE
-    or TRACE_APPROX or TRACE_APPROX_CANDIDATES or TRACE_APPROX_MATCHES
-    or TRACE_INDEXING_PERF):
+if (
+    TRACE
+    or TRACE_APPROX
+    or TRACE_APPROX_CANDIDATES
+    or TRACE_APPROX_MATCHES
+    or TRACE_INDEXING_PERF
+    or TRACE_SPDX_LID
+):
 
     use_print = True
 
@@ -505,11 +511,20 @@ class LicenseIndex(object):
                 logger_debug('  MATCHED QUERY TEXT:', qt)
                 logger_debug('  MATCHED RULE TEXT:', it)
 
-    def get_spdx_id_matches(self, query, from_spdx_id_lines=True, **kwargs):
+    def get_spdx_id_matches(
+        self,
+        query,
+        from_spdx_id_lines=True,
+        expression_symbols=None,
+        **kwargs,
+    ):
         """
         Matching strategy for SPDX-Licensed-Identifier style of expressions. If
         `from_spdx_id_lines` is True detect only in the SPDX license identifier
         lines found in the query. Otherwise use the whole query for detection.
+
+        Use the ``expression_symbols`` mapping of {lowered key: LicenseSymbol}
+        if provided. Otherwise use the standard SPDX license symbols.
         """
         matches = []
 
@@ -528,11 +543,18 @@ class LicenseIndex(object):
         for query_run, detectable_text in qrs_and_texts:
             if not query_run.matchables:
                 continue
+            if TRACE_SPDX_LID:
+                logger_debug(
+                    'get_spdx_id_matches:',
+                    'query_run:', query_run,
+                    'detectable_text:', detectable_text,
+                )
 
             spdx_match = match_spdx_lid.spdx_id_match(
                 idx=self,
                 query_run=query_run,
                 text=detectable_text,
+                expression_symbols=expression_symbols,
             )
 
             if spdx_match:
@@ -762,6 +784,7 @@ class LicenseIndex(object):
         query_string=None,
         min_score=0,
         as_expression=False,
+        expression_symbols=None,
         approximate=True,
         deadline=sys.maxsize,
         _skip_hash_match=False,
@@ -777,6 +800,9 @@ class LicenseIndex(object):
         If `as_expression` is True, treat the whole text as a single SPDX
         license expression and use only expression matching.
 
+        Use the ``expression_symbols`` mapping of {lowered key: LicenseSymbol}
+        if provided. Otherwise use the standard SPDX license symbols mapping.
+
         If `approximate` is True, perform approximate matching as a last
         matching step. Otherwise, only do hash, exact and expression matching.
 
@@ -813,9 +839,13 @@ class LicenseIndex(object):
                 match.set_lines(matches, qry.line_by_pos)
                 return matches
 
-        # TODO: add matching to degenerated expressions with custom symbols
+        get_spdx_id_matches = partial(
+            self.get_spdx_id_matches,
+            expression_symbols=expression_symbols,
+        )
+
         if as_expression:
-            matches = self.get_spdx_id_matches(qry, from_spdx_id_lines=False)
+            matches = get_spdx_id_matches(qry, from_spdx_id_lines=False)
             match.set_lines(matches, qry.line_by_pos)
             return matches
 
@@ -829,7 +859,7 @@ class LicenseIndex(object):
         matchers = [
             # matcher, include_low in post-matching remaining matchable check
             (self.get_exact_matches, False, 'aho'),
-            (self.get_spdx_id_matches, True, 'spdx_lid'),
+            (get_spdx_id_matches, True, 'spdx_lid'),
         ]
 
         if approximate:
@@ -841,17 +871,25 @@ class LicenseIndex(object):
                 logger_debug()
                 logger_debug('matching with matcher:', matcher_name)
 
-            matched = matcher(qry, matched_qspans=already_matched_qspans,
-                              existing_matches=matches, deadline=deadline)
+            matched = matcher(
+                qry,
+                matched_qspans=already_matched_qspans,
+                existing_matches=matches,
+                deadline=deadline,
+            )
+
             if TRACE:
                 self.debug_matches(
-                    matches=matched, message='matched with: ' + matcher_name,
-                    location=location, query_string=query_string)  # , with_text, query)
+                    matches=matched,
+                    message='matched with: ' + matcher_name,
+                    location=location,
+                    query_string=query_string,
+                )
 
             matched = match.merge_matches(matched)
             matches.extend(matched)
 
-            # subtract whole text matched if this is long enough
+            # Subtract whole text matched if this is long enough
             for m in matched:
                 if (m.rule.is_license_text
                     and m.rule.length > 120
@@ -859,10 +897,10 @@ class LicenseIndex(object):
                 ):
                     qry.subtract(m.qspan)
 
-            # check if we have some matchable left do not match futher if we do
+            # Check if we have some matchable left do not match futher if we do
             # not need to collect qspans matched exactly e.g. with coverage 100%
             # this coverage check is because we have provision to match
-            # fragments (unused for now)
+            # fragments (unused for now).
 
             already_matched_qspans.extend(
                 m.qspan for m in matched if m.coverage() == 100)
